@@ -34,7 +34,7 @@ sub readopts {
 		close CONCAT;
 	}
 
-	return ('-f', 'concat', '-safe', '0', $self->SReview::Video::readopts());
+	return ('-f', 'concat', '-safe', '0', '-auto_convert', '1', $self->SReview::Video::readopts());
 }
 
 sub _build_duration {
