@@ -22,11 +22,16 @@
  * including all its JavaScript.
  */
 sreview_viddata.init = function() {
+	// the length adjust value that was used for the currently-generated videos
 	this.current_length_adj = this.corrvals.length_adj;
+	// the offset value that was used for the currently-generated videos
 	this.current_offset = this.corrvals.offset_start;
 	this.lengths = {
+		// the length of the current pre video
 		"pre": this.prelen,
+		// the scheduled length of the talk
 		"main_initial": this.mainlen,
+		// the length of the current post video
 		"post": this.postlen
 	};
 	this.startpoints = {
@@ -46,14 +51,23 @@ sreview_viddata.point_to_abs = function(which, where) {
 	return where + this.startpoints[which];
 };
 
+sreview_viddata.abs_to_point = function(which, abs) {
+	return abs - this.startpoints[which];
+};
+
 sreview_viddata.abs_to_offset = function(abs) {
 	return abs - this.startpoints.main + this.current_offset;
 };
 
 sreview_viddata.abs_to_adj = function(abs) {
-	return abs - this.startpoints.post + this.current_length_adj - this.newpoints.start;
+	let newlen = abs - this.newpoints.start;
+	return newlen - this.lengths.main_initial;
 };
 
+sreview_viddata.totlen = function() {
+	return this.lengths.pre + this.lengths.main_initial + this.lengths.post + this.corrvals.length_adj;
+}
+
 sreview_viddata.set_point = function(which, what, where) {
 	// which = which video (pre/main/post)
 	// what = what point to set (start/end)
@@ -61,6 +75,16 @@ sreview_viddata.set_point = function(which, what, where) {
 	this.newpoints[what] = this.point_to_abs(which, where);
 };
 
+sreview_viddata.abs_to_vid = function(abs) {
+	if(abs < this.startpoints.main) {
+		return "pre";
+	}
+	if(abs < this.startpoints.post) {
+		return "main";
+	}
+	return "post";
+};
+
 sreview_viddata.get_start_offset = function() {
 	return this.abs_to_offset(this.newpoints.start);
 };
